@@ -17,18 +17,18 @@ use Feature::Compat::Try;
 use Future::AsyncAwait;
 use Object::Pad 0.821;
 
-class Sys::Async::Virt::Callback v0.1.2;
+class Sys::Async::Virt::Callback v0.1.3;
 
 
 use Carp qw(croak);
 use Future::Queue;
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.1.2;
+use Protocol::Sys::Virt::Remote::XDR v0.1.3;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
-field $_id :param :reader;
-field $_client :param :reader;
+field $_id              :reader :param;
+field $_client          :reader :param;
 field $_deregister_call :param;
 field $_queue;
 field $_cancelled;
@@ -93,7 +93,7 @@ Sys::Async::Virt::Callback - Client side proxy to remote LibVirt event source
 
 =head1 VERSION
 
-v0.1.2
+v0.1.3
 
 =head1 SYNOPSIS
 
